pub enum AdcCalibUnit {
ADC1,
}Available on crate feature
unstable only.Expand description
Selects which ADC the eFuse calibration data applies to.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Variants
ADC1
Selects efuse calibration data for ADC1.